@@ -1253,12 +1253,16 @@ nextgen:
       }
    }
 
-   /* set the new bounding box */
+   /* Set the new bounding box.  In pathological cases, such as a page	*/
+   /* with only pin labels, the bounds may not have been changed from	*/
+   /* their initial values.  If so, then don't touch the bounding box.	*/
 
-   thisobj->bbox.lowerleft.x = llx;
-   thisobj->bbox.lowerleft.y = lly;
-   thisobj->bbox.width = urx - llx;
-   thisobj->bbox.height = ury - lly;
+   if ((llx < urx) && (lly < ury)) {
+      thisobj->bbox.lowerleft.x = llx;
+      thisobj->bbox.lowerleft.y = lly;
+      thisobj->bbox.width = urx - llx;
+      thisobj->bbox.height = ury - lly;
+   }
 
    /* calculate instance-specific values */
    calcbboxinst(thisinst);
@@ -1825,6 +1829,7 @@ void UDrawObject(objinstptr theinstance, short level, int passcolor, pushlistptr
    short	tmpwidth;
    int		defaultcolor = passcolor;
    int		curcolor = passcolor;
+   int		thispart;
    XPoint 	bboxin, bboxout[2];
    u_char	xm, ym;
    objectptr	theobject = theinstance->thisobject;
@@ -1862,9 +1867,11 @@ void UDrawObject(objinstptr theinstance, short level, int passcolor, pushlistptr
      XSetLineAttributes(dpy, areastruct.gc, tmpwidth >= 2.0 ? (int)tmpwidth :
 		0, LineSolid, CapRound, JoinBevel);
 
-     for (areagen = theobject->plist; areagen < theobject->plist +
-           theobject->parts; areagen++) {
+     /* guard against plist being regenerated during a redraw by the	*/
+     /* expression parameter mechanism (should that be prohibited?)	*/
 
+     for (thispart = 0; thispart < theobject->parts; thispart++) {
+       areagen = theobject->plist + thispart;
        if ((*areagen)->type & DRAW_HIDE) continue;
 
        if (defaultcolor != DOFORALL) {
